from datetime import datetime, timedelta
from korean_lunar_calendar import KoreanLunarCalendar

def get_saturday_of_week(date):
    days_to_add = (5 - date.weekday()) % 7
    return date + timedelta(days=days_to_add)

calendar = KoreanLunarCalendar()
today = datetime.today()
saturday_of_week = get_saturday_of_week(today)

calendar.setSolarDate(saturday_of_week.year, saturday_of_week.month, saturday_of_week.day)
lunar_year, lunar_month, lunar_day = calendar.LunarIsoFormat().split('-')

# 'Intercalation' 부분을 제거합니다.
lunar_day = lunar_day.split()[0]

last_digit = int(lunar_day) % 10
print(f"이번 주 토요일의 한국 음력 날짜: {lunar_year}년 {lunar_month}월 {lunar_day}일")
print(f"음력 날짜 끝수: {last_digit}")

# 사용자 입력 부분을 제거하고, last_digit을 바로 input_num에 할당합니다.
input_num = last_digit

# 나머지 코드는 변경 없이 사용합니다.

import datetime

days = ["월요일", "화요일", "수요일", "목요일", "금요일", "토요일", "일요일"]

def get_today_days():
    return days[datetime.datetime.today().weekday()]

today = get_today_days()
days_to_saturday = (5 - days.index(today)) % 7  
saturday = datetime.datetime.now() + datetime.timedelta(days=days_to_saturday)

result = int(saturday.strftime('%d')[-1]) + 10, int(saturday.strftime('%d')[-1]) + 20, int(saturday.strftime('%d')[-1]) + 30, int(saturday.strftime('%d')[-1]) + 40

result_str = ",".join(str(num) for num in result if 1 <= num <= 45)
result_str_tab = "\t".join(str(num) for num in result if 1 <= num <= 45)


def add_numbers(num):
    result = []
    for i in range(4):
        added_num = num + (i+1)*10
        if added_num <= 45:
            result.append(str(added_num))
    return ','.join(result), '\t'.join(result)

# input_num = int(input("음력날짜 끝수 입력: "))

print()
print("양력날짜끝수 제외:",saturday.strftime('%d')[-1] + "," + result_str)
print(f"음력날짜끝수 제외: {input_num},{add_numbers(input_num)[0]}")
print()
print(saturday.strftime('%d')[-1] + "\t" + result_str_tab)
print(f"{input_num}\t{add_numbers(input_num)[1]}")
print()

import requests
import json
from datetime import datetime, timedelta

def get_current_draw_no():
    lower_bound = 1
    upper_bound = 10000
    while lower_bound <= upper_bound:
        middle = (lower_bound + upper_bound) // 2
        url = f"https://www.dhlottery.co.kr/common.do?method=getLottoNumber&drwNo={middle}"
        response = requests.get(url)
        data = json.loads(response.text)
        if data['returnValue'] == 'fail':
            upper_bound = middle - 1
        else:
            lower_bound = middle + 1
    return upper_bound

def get_last_saturday_draw_no(current_draw_no):
    today = datetime.today()
    day_of_week = today.weekday()  # 0: Monday, 1: Tuesday, ..., 6: Sunday
    days_since_last_saturday = (day_of_week - 5) % 7
    last_saturday = today - timedelta(days=days_since_last_saturday)
    days_since_first_draw = (last_saturday - datetime(2002, 12, 7)).days
    weeks_since_first_draw = days_since_first_draw // 7

    return weeks_since_first_draw + 1

def get_lotto_result(draw_no):
    url = f"https://www.dhlottery.co.kr/common.do?method=getLottoNumber&drwNo={draw_no}"
    response = requests.get(url)
    data = json.loads(response.text)

    if data['returnValue'] == 'success':
        winning_numbers = [data[f'drwtNo{i}'] for i in range(1, 7)]
        bonus_number = data['bnusNo']
        return winning_numbers, bonus_number
    else:
        return None, None

if __name__ == "__main__":
    current_draw_no = get_current_draw_no()
    last_saturday_draw_no = get_last_saturday_draw_no(current_draw_no)
    winning_numbers, bonus_number = get_lotto_result(last_saturday_draw_no)

    if winning_numbers and bonus_number:
        print(f"직전 토요일(회차 {last_saturday_draw_no}) 로또 당첨번호:")
        print(", ".join(map(str, winning_numbers)), end=", ")
        print(f"보너스 번호: {bonus_number}")
    else:
        print("당첨 정보를 불러오지 못했습니다.")

import tkinter as tk

def button_click(num):
    row = (num - 1) // 7
    col = (num - 1) % 7

    for i in range(7):
        for j in range(7):
            button_num = i * 7 + j + 1
            if button_num <= 45:
                if abs(i - row) == abs(j - col):  # 대각선 조건 체크
                    if button_num not in clicked_numbers:
                        clicked_numbers.append(button_num)
                        buttons[button_num - 1].configure(bg='yellow')
                    else:
                        # 이미 클릭된 번호를 다시 클릭하면 아무 작업도 수행하지 않는다.
                        pass
                else:
                    unclicked_numbers = list(set(numbers) - set(clicked_numbers))
                    if button_num in unclicked_numbers:
                        buttons[button_num - 1].configure(bg='SystemButtonFace', state='normal')
                    elif button_num in clicked_numbers:
                        # 이미 클릭된 번호를 클릭 가능하게 설정한다.
                        buttons[button_num - 1].configure(state='normal')


def enter_key(event):
    unclicked_numbers = list(set(numbers) - set(clicked_numbers))
    unclicked_numbers.sort()  # 추가: 대각선 제외 숫자를 오름차순으로 정렬
    if len(clicked_numbers) > 1:
        # print("대각수:", ",".join(str(x) for x in clicked_numbers))
        print()
        print()
        print("대각제외:", ",".join(str(x) for x in unclicked_numbers))
        print("대각제외:", end=' ')
        for i, num in enumerate(unclicked_numbers):
            print(num, end='\t' if (i+1)%10 else '\n')
        print()

    

root = tk.Tk()
root.attributes('-topmost', True)  # 추가: 창이 항상 위에 뜨도록 설정

clicked_numbers = []
buttons = []
numbers = list(range(1, 46))

for i in range(7):
    for j in range(7):
        num = i * 7 + j + 1
        if num <= 45:
            button = tk.Button(root, text=str(num), width=4, height=2, command=lambda num=num: button_click(num))
            button.grid(row=i, column=j)
            buttons.append(button)

root.bind('<Return>', enter_key)
root.mainloop()

